DebugDumpResult class final

Results from a Flutter debug dump call.

Constructors

DebugDumpResult({required String kind, required String content})
Creates a debug dump result.
const

Properties

content String
The dumped text content.
final
hashCode int
The hash code for this object.
no setterinherited
kind String
The kind of dump (app, render, layer, focus, semantics).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
JSON-compatible representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited