ProfileMethodInspectionStatus enum
The lookup state for a method inspection request.
Values
- found → const ProfileMethodInspectionStatus
-
A single matching method was found.
- ambiguous → const ProfileMethodInspectionStatus
-
The requested query matched multiple methods.
- notFound → const ProfileMethodInspectionStatus
-
The requested query did not match any methods.
-
The underlying profile did not have enough raw data to inspect methods.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parse(
String value) → ProfileMethodInspectionStatus - Parses a wire value.
Constants
-
values
→ const List<
ProfileMethodInspectionStatus> - A constant List of the values in this enum, in order of their declaration.