ProfileMethodSearchStatus enum

Availability state for method search against a profile target.

Inheritance
Available extensions

Values

available → const ProfileMethodSearchStatus

Method-table data was available and the search ran.

unavailable → const ProfileMethodSearchStatus

Method-table data was unavailable for the selected profile.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String value) ProfileMethodSearchStatus
Parses a wire value.

Constants

values → const List<ProfileMethodSearchStatus>
A constant List of the values in this enum, in order of their declaration.