ProfileTrendStep class

A consecutive step in a multi-session trend series.

Constructors

ProfileTrendStep({required String baselineId, required String currentId, required ProfileRegionComparison comparison, required ProfileRegressionSummary regressions})
Creates a trend step.
const

Properties

baselineId String
Baseline entry label.
final
comparison ProfileRegionComparison
Structured profile comparison for this step.
final
currentId String
Current entry label.
final
hashCode int
The hash code for this object.
no setterinherited
regressions ProfileRegressionSummary
Regression summary for this step.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Converts this step to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited