ShaderCompilationEvent class final

A timeline event related to shader compilation.

Constructors

ShaderCompilationEvent({required String name, required double durationUs, required String category})
Creates a shader compilation event.
const

Properties

category String
Category: 'skia', 'impeller', 'gpu', or 'other'.
final
durationUs double
Duration in microseconds.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The event name (e.g. GrGLProgramBuilder, Program::compile).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
JSON-compatible representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited