TimelineHotspot class final

A hotspot insight extracted from the VM timeline.

Constructors

TimelineHotspot({required String name, required double selfDurationUs, required double totalDurationUs, required int callCount, required double maxDurationUs})
Creates a timeline hotspot.
const

Properties

callCount int
Number of times this event occurred.
final
hashCode int
The hash code for this object.
no setterinherited
maxDurationUs double
Maximum single duration in microseconds.
final
name String
The event name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfDurationUs double
Self (exclusive) duration in microseconds.
final
totalDurationUs double
Total (inclusive) duration in microseconds.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
JSON-compatible representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited