WidgetInspectorQueryResult class final

The result of a Flutter widget inspector service query.

Constructors

WidgetInspectorQueryResult({required String method, required String isolateId, required Object? result})
Creates a widget inspector query result.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isolateId String
The isolate that handled the query.
final
method String
The service extension method that was invoked.
final
result Object?
The decoded response payload.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
JSON-compatible representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited