AllocationAttribution class
A single allocation-attribution entry for a memory class, showing the top call sites that were on the CPU stack during its growth.
Constructors
Properties
- allocatedBytes → int
-
Number of bytes allocated for this class in the capture window.
final
- allocatedInstances → int
-
Number of instances allocated for this class in the capture window.
final
-
callSiteFractions
→ List<
(String, double)> -
Top call sites and their fraction of CPU samples, sorted descending.
Each entry is (functionName, fraction) where fraction is 0.0-1.0.
final
- className → String
-
The name of the class being allocated.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- libraryUri → String?
-
The library URI where the class is defined.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Serializes this attribution entry to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited