MemoryClassEntry class final
A single class allocation entry from a memory snapshot.
Constructors
- MemoryClassEntry({required String className, required int instancesCurrent, required int instancesAccumulated, required int sizeCurrent, required int sizeAccumulated})
-
Creates a memory class entry.
const
- MemoryClassEntry.fromClassHeapStats(ClassHeapStats stats)
-
Deserializes from an
AllocationProfileclass entry.factory
Properties
- className → String
-
The class name.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- instancesAccumulated → int
-
Total instances accumulated (including collected).
final
- instancesCurrent → int
-
Current number of live instances.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeAccumulated → int
-
Total heap size in bytes accumulated (including collected).
final
- sizeCurrent → int
-
Current heap size in bytes.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - JSON-compatible representation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited