ProfileHotspotPath class
A representative call path for a hotspot insight.
Constructors
-
ProfileHotspotPath({required ProfileCallTreeView view, required List<
ProfileHotspotPathFrame> frames}) - Creates a hotspot path.
Properties
-
frames
→ List<
ProfileHotspotPathFrame> -
Ordered frames from root to hotspot.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- view → ProfileCallTreeView
-
The call tree view used for the path.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this path to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited