ProfileMethodRelationDelta class
A delta for a caller or callee relation on a selected method.
Constructors
- ProfileMethodRelationDelta({required String methodId, required String name, required String kind, required ProfileNumericDelta sampleCount, required ProfileNumericDelta percent, String? location})
-
Creates a relation delta.
const
-
ProfileMethodRelationDelta.fromJson(Map<
String, Object?> json) -
Deserializes a relation delta from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → String
-
The VM-reported frame kind.
final
- location → String?
-
Source location for the related method, when available.
final
- methodId → String
-
Stable identifier for the related method.
final
- name → String
-
Display name of the related method.
final
- percent → ProfileNumericDelta
-
Percentage delta for this edge.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleCount → ProfileNumericDelta
-
Weighted sample-count delta for this edge.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Converts this delta to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited