WidgetTreeCaptureService class
Captures Flutter widget trees from a running application via VM service extension calls.
Constructors
- WidgetTreeCaptureService({required VmService vmService})
- Creates a widget tree capture service.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
captureSummaryWidgetTree(
{required String isolateId, int maxDepth = 15, bool projectOnly = false}) → Future< WidgetTreeCapture> - Captures the widget tree as a summary (Flutter-only widgets, no children details).
-
captureWidgetTree(
{required String isolateId, int maxDepth = 15, bool projectOnly = false}) → Future< WidgetTreeCapture> -
Captures the widget tree from
isolateId. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited